function [sumP,P]=APTERp(model,Y,delta,v)
% Exponential Weighted Experts for Survival (sEWE)
%
% >> p=APTER(X,Y,v)
% >> [p,P]=APTER(X,Y,v)
%
% Input:
% 'X' covariate: is a matrix of n x d
% 'Y' time: is a vector of n elements
% 'v' a parameter: is a scalar
%
% Output:
% 'p' the last p vector: is a vector of d elements
% 'P' all the p vectors: is a matrix of n x d elements
%
% Author: Liu,Yang (liu.yang@it.uu.se)

if nargin==1
    [~,X,Y,delta,v]=ungroup(model);
else
    X=model;
end


% Get the size of X
[n,d]=size(X);
m=d;

% Rearrange X and Y based on sorted Y
[Y,events]=sort(Y);
X=X(events,:);

% Assign the initial values of p
p=(1/m)*ones(1,m);
P(n,:)=p;
% Start the loop
for t=1:n-1
    % Calculate the loss
        
    Rt=find(Y(t)>Y & delta==1);
    if isempty(Rt)
        Ltf=0.5*ones(1,m);
    else
    Yd=Y(Rt)-Y(t);
    XX=X(Rt,:);
    Xd=XX-repmat(X(t,:),size(XX,1),1);
    I=repmat(Yd,1,size(Xd,2)).*Xd<0;
    Ltf=sum(I)/length(Rt);
    end
    
    % Calculate and update p
    eLtf=exp(-v*Ltf);    
    p=(eLtf)/sum(eLtf);
    
    % Save each p vector
    P(t,:)=p;
end

sumP=mean(P)';