function [testmean, trainmean] = CV2(model,K)
% A K-fold cross validation function to test
% the performance of a model for a selected database
%
% >> testmean = CV2(model,K)
% >> [testmean, trainmean] = CV2(model,K)
%
% Input
% 'model' is a structure which includes the fields 'func','X','Y','delta','gam','mu'
% 'K' number of folds: is a scalar
%
% Output
% testmean the mean of the c-index on K-fold test:  is a scalar
% trainmean the mean of the c-index on K-fold test:  is a scalar
%
% Author: Liu,Yang (liu.yang@it.uu.se)

% Set the size of trainning and test sets
n=size(model.X,1);
ntrain=ceil(n/K*(K-1));
ntest=n-ntrain;

% Cut the model
[trainmodel,testmodel]=seperatemodel(model,ntest+1:n,1:ntest);
% Solve it
w=feval(trainmodel.func,trainmodel);
testmean=cindex(testmodel.X*w,testmodel.Y,testmodel.delta);
trainmean=cindex(trainmodel.X*w,trainmodel.Y,trainmodel.delta);