function [a,Yt] = minlip_kernelly(model,Y,delta,gam,kernel,par,Xt)
% Implementation of kernel minlip using Yalmip
% Use censored failure time data
% event(not censored): delta=1;  censored: delta=0
%
% Author: Liu,Yang (liu.yang@it.uu.se)

% Selection of input format
if nargin==1
    [~,X,Y,delta,gam,~,kernel,par,Xt]=ungroup(model);
else
    X=model;
end

[n,d]=size(X);

% Sort by Y
[Y,events] = sort(Y);
X= X(events,:);
delta=delta(events,:);

K=kernel_matrix(X,kernel,par);
% Build matrix D and Dc
% Dc = makediff3(Y,delta);
Dc=buildDMatrix(n,delta,Y);
%Dc=MakeDiff2(Y,1-delta);
ne=size(Dc,1);
A = [-Dc'; Dc'];
b = [gam*ones(n,1); gam*ones(n,1)];

% Solve QP by solver
yalmip('clear');
a=sdpvar(ne,1);
solvesdp([A*a<=b,a>=0],...
    1/2*a'*Dc*K*Dc'*a-a'*Dc*Y,...  
    sdpsettings('solver','mosek','verbose',0,'cachesolvers',1));

% ep=sdpvar(n,1);
% solvesdp([Dc*(X*a+ep)>=Dc*Y],...
%     a'*a+gam*norm(ep,1),...  
%     sdpsettings('solver','mosek','verbose',0,'cachesolvers',1));


% solvesdp([a>=0],...
%     1/2*a'*Dc*K*Dc'*a-a'*Dc*Y,...  
%     sdpsettings('solver','mosek','verbose',0,'cachesolvers',1));

% solvesdp([Dc*X*a>=Dc*Y],...
%     1/2*a'*a,...  
%     sdpsettings('solver','mosek','verbose',0,'cachesolvers',1));

% Convert the result to double type
a=double(a);
Yt=(a'*Dc*kernel_matrix(X,kernel,par,Xt))';

% Yt=Xt*a;
% Yh = kernel_matrix(X,kernel,par)*Dc'*a;
% Yh(events)  = Yh;
% ci=cindex(Yt,Y,delta)
% plot(Yh,Y,'.');