function [x,xtest,y,ytest,deltatrain,deltatest]=seperatemodel(model,indtrain,indtest,perm)
% A seperatemodel function to seperatemodel the model data to two parts based on a permute
%
% >> [trainmodel,testmodel]=seperatemodel(model,indtrain,indtest)
% >> [trainmodel,testmodel]=seperatemodel(model,indtrain,indtest,perm)
% >> [x,xtest,y,ytest,deltatrain,deltatest]=seperatemodel(model,indtrain,indtest)
% >> [x,xtest,y,ytest,deltatrain,deltatest]=seperatemodel(model,indtrain,indtest,perm)
%
% Input
% 'model' is a structure which includes the fields 'func','X','Y','delta','gam','mu'
% 'indtrain' is a n1 vector indicates the index of the training set
% 'indtest' is a n2 vector indicates the index of the test set
% 'perm' is a n vector indicates the random permute
%
% Output
% CASE 1: Structure format:
% 'trainmodel' the training set: is a structure
% 'testmodel' the test set: is a structure
%
% CASE 2: Original format:
% 'x' input of train set: is a matrix of n1 x d
% 'xtest' input of test set: is a matrix of n2 x d
% 'y' output of train set: is a vector of n1 elements
% 'ytest' output of test set: is a vector of n2 elements
% 'deltatrain' censoring of train set: is a vector of n1 elements
% 'deltatest' censoring of test set: is a vector of n2 elements
%
% Author: Liu,Yang (liu.yang@it.uu.se)


if nargin>3
    indtrain=perm(indtrain);
    indtest=perm(indtest);
end

[func,X,Y,delta,gam,miu,kernel,par,Xt]=ungroup(model);

deltatrain=delta(indtrain);
deltatest=delta(indtest);
x=X(indtrain,:);
y=Y(indtrain);
xtest=X(indtest,:);
ytest=Y(indtest);

if nargout<6
    x=buildmodel(func,x,y,deltatrain,gam,miu,kernel,par,Xt);
    xtest=buildmodel(func,xtest,ytest,deltatest,gam,miu,kernel,par,Xt);
end
    