function bestpars = tune(model,tunemethod,tunemethodpar,testmethod,testpar)
% Model selection for minli,minlipl1,minlipp,model2,model2p,...
%
% >> model = tune(model,tunemethod,tunemethodpar,testmethod,testpar)
%
% Input:
% 'model' is a structure which includes the fields 'func','X','Y','delta','gam','mu'
% 'tunemethod' is the name of tune testmethod: is a string ('linesearch','gridsearch','csa')
% 'tunemethodpar' is the parameters setting of the tune testmethod ({left,right,interval length,threshold})
% 'testmethod' is a string of the name of the test testmethod we use ('CV','CV2')
% 'testpar' is the parameters setting of the test testmethod ({K})
%
% Output:
% bestpars is a vector include the best parameters we often running
%
% Author: Liu,Yang (liu.yang@it.uu.se)

if strcmp(tunemethod,'linesearch')
    bestgam=linesearch(model,tunemethodpar,testmethod,testpar);
    bestpars=[bestgam];
end

if strcmp(tunemethod,'linesearch2')
    bestgam=linesearch(model,tunemethodpar,testmethod,testpar);
    bestpars=[bestgam];
end

if strcmp(tunemethod,'linesearch_noexp')
    bestgam=linesearch_noexp(model,tunemethodpar,testmethod,testpar);
    bestpars=[bestgam];
end

if strcmp(tunemethod,'csa')
    bestc=csa(tunemethodpar,@scv,model,testmethod,testpar);
    bestgam=exp(bestc);
    bestpars=[bestgam];
end

if strcmp(tunemethod,'gridsearch')
    [bestgam,bestmu]=gridsearch(model,tunemethodpar,testmethod,testpar);
    bestpars=[bestgam,bestmu];
end

if strcmp(tunemethod,'gridsearchk')
    [bestgam,bestpar]=gridsearchk(model,tunemethodpar,testmethod,testpar);
    bestpars=[bestgam,bestpar];
end

if strcmp(tunemethod,'gridsearch22')
    [bestgam,bestmu]=gridsearch2(model,tunemethodpar,testmethod,testpar);
    bestpars=[bestgam,bestmu];
end